package DBIx::SQLstate::wikipedia;

our $VERSION = '20230517.1200';

our %SQLstate = (
    '00000' => 'successful completion',
    '01000' => 'warning',
    '01001' => 'cursor operation conflict',
    '01002' => 'disconnect error',
    '01003' => 'null value eliminated in set function',
    '01004' => 'string data, right truncation',
    '01005' => 'insufficient item descriptor areas',
    '01006' => 'privilege not revoked',
    '01007' => 'privilege not granted',
    '01009' => 'search condition too long for information schema',
    '0100A' => 'query expression too long for information schema',
    '0100B' => 'default value too long for information schema',
    '0100C' => 'result sets returned',
    '0100D' => 'additional result sets returned',
    '0100E' => 'attempt to return too many result sets',
    '0100F' => 'statement too long for information schema',
    '01010' => 'column cannot be mapped',
    '01011' => 'SQL-Java path too long for information schema',
    '01012' => 'invalid number of conditions',
    '0102F' => 'array data, right truncation',
    '02000' => 'no data',
    '02001' => 'no additional result sets returned',
    '07000' => 'dynamic SQL error',
    '07001' => 'using clause does not match dynamic parameter specifications',
    '07002' => 'using clause does not match target specifications',
    '07003' => 'cursor specification cannot be executed',
    '07004' => 'using clause required for dynamic parameters',
    '07005' => 'prepared statement not a cursor specification',
    '07006' => 'restricted data type attribute violation',
    '07007' => 'using clause required for result fields',
    '07008' => 'invalid descriptor count',
    '07009' => 'invalid descriptor index',
    '0700B' => 'data type transform function violation',
    '0700C' => 'undefined DATA value',
    '0700D' => 'invalid DATA target',
    '0700E' => 'invalid LEVEL value',
    '0700F' => 'invalid DATETIME_INTERVAL_CODE',
    '08000' => 'connection exception',
    '08001' => 'SQL-client unable to establish SQL-connection',
    '08002' => 'connection name in use',
    '08003' => 'connection does not exist',
    '08004' => 'SQL-server rejected establishment of SQL-connection',
    '08006' => 'connection failure',
    '08007' => 'transaction resolution unknown',
    '09000' => 'triggered action exception',
    '0A000' => 'feature not supported',
    '0A001' => 'multiple server transactions',
    '0D000' => 'invalid target type specification',
    '0E000' => 'invalid schema name list specification',
    '0F000' => 'locator exception',
    '0F001' => 'invalid specification',
    '0K000' => 'resignal when handler not active',
    '0L000' => 'invalid grantor',
    '0M000' => 'invalid SQL-invoked procedure reference',
    '0N000' => 'SQL/XML mapping error',
    '0N001' => 'unmappable XML name',
    '0N002' => 'invalid XML character',
    '0P000' => 'invalid role specification',
    '0S000' => 'invalid transform group name specification',
    '0T000' => 'target table disagrees with cursor specification',
    '0U000' => 'attempt to assign to non-updatable column',
    '0V000' => 'attempt to assign to ordering column',
    '0W000' => 'prohibited statement encountered during trigger execution',
    '0W001' => 'modify table modified by data change delta table',
    '0X000' => 'invalid foreign server specification',
    '0Y000' => 'pass-through specific condition',
    '0Y001' => 'invalid cursor option',
    '0Y002' => 'invalid cursor allocation',
    '0Z000' => 'diagnostics exception',
    '0Z001' => 'maximum number of stacked diagnostics areas exceeded',
    '0Z002' => 'stacked diagnostics accessed without active handler',
    '10000' => 'XQuery error',
    '20000' => 'case not found for case statement',
    '21000' => 'cardinality violation',
    '22000' => 'data exception',
    '22001' => 'string data, right truncation',
    '22002' => 'null value, no indicator parameter',
    '22003' => 'numeric value out of range',
    '22004' => 'null value not allowed',
    '22005' => 'error in assignment',
    '22006' => 'invalid interval format',
    '22007' => 'invalid datetime format',
    '22008' => 'datetime field overflow',
    '22009' => 'invalid time zone displacement value',
    '2200B' => 'escape character conflict',
    '2200C' => 'invalid use of escape character',
    '2200D' => 'invalid escape octet',
    '2200E' => 'null value in array target',
    '2200F' => 'zero-length character string',
    '2200G' => 'most specific type mismatch',
    '2200H' => 'sequence generator limit exceeded',
    '2200J' => 'nonidentical notations with the same name',
    '2200K' => 'nonidentical unparsed entities with the same name',
    '2200L' => 'not an XML document',
    '2200M' => 'invalid XML document',
    '2200N' => 'invalid XML content',
    '2200P' => 'interval value out of range',
    '2200Q' => 'multiset value overflow',
    '2200R' => 'XML value overflow',
    '2200S' => 'invalid comment',
    '2200T' => 'invalid processing instruction',
    '2200U' => 'not an XQuery document node',
    '2200V' => 'invalid XQuery context item',
    '2200W' => 'XQuery serialization error',
    '22010' => 'invalid indicator parameter value',
    '22011' => 'substring error',
    '22012' => 'division by zero',
    '22013' => 'invalid preceding or following size in window function',
    '22014' => 'invalid argument for NTILE function',
    '22015' => 'interval field overflow',
    '22016' => 'invalid argument for NTH_VALUE function',
    '22017' => 'invalid data specified for datalink',
    '22018' => 'invalid character value for cast',
    '22019' => 'invalid escape character',
    '2201A' => 'null argument passed to datalink constructor',
    '2201B' => 'invalid regular expression',
    '2201C' => 'null row not permitted in table',
    '2201D' => 'datalink value exceeds maximum length',
    '2201E' => 'invalid argument for natural logarithm',
    '2201F' => 'invalid argument for power function',
    '2201G' => 'invalid argument for width bucket function',
    '2201H' => 'invalid row version',
    '2201J' => 'XQuery sequence cannot be validated',
    '2201K' => 'XQuery document node cannot be validated',
    '2201L' => 'no XML schema found',
    '2201M' => 'element namespace not declared',
    '2201N' => 'global element not declared',
    '2201P' => 'no XML element with the specified QName',
    '2201Q' => 'no XML element with the specified namespace',
    '2201R' => 'validation failure',
    '2201S' => 'invalid Query regular expression',
    '2201T' => 'invalid Query option flag',
    '2201U' => 'attempt to replace a zero-length string',
    '2201V' => 'invalid Query replacement string',
    '2201W' => 'invalid row count in fetch first clause',
    '2201X' => 'invalid row count in result offset clause',
    '22021' => 'character not in repertoire',
    '22022' => 'indicator overflow',
    '22023' => 'invalid parameter value',
    '22024' => 'unterminated C string',
    '22025' => 'invalid escape sequence',
    '22026' => 'string data, length mismatch',
    '22027' => 'trim error',
    '22029' => 'noncharacter in UCS string',
    '2202A' => 'null value in field reference',
    '2202D' => 'null value substituted for mutator subject parameter',
    '2202E' => 'array element error',
    '2202F' => 'array data, right truncation',
    '2202G' => 'invalid repeat argument in a sample clause',
    '2202H' => 'invalid sample size',
    '23000' => 'integrity constraint violation',
    '23001' => 'restrict violation',
    '24000' => 'invalid cursor state',
    '25000' => 'invalid transaction state',
    '25001' => 'active SQL-transaction',
    '25002' => 'branch transaction already active',
    '25003' => 'inappropriate access mode for branch transaction',
    '25004' => 'inappropriate isolation level for branch transaction',
    '25005' => 'no active SQL-transaction for branch transaction',
    '25006' => 'read-only SQL-transaction',
    '25007' => 'schema and data statement mixing not supported',
    '25008' => 'held cursor requires same isolation level',
    '26000' => 'invalid SQL statement name',
    '27000' => 'triggered data change violation',
    '27001' => 'modify table modified by data change delta table',
    '28000' => 'invalid authorization specification',
    '2B000' => 'dependent privilege descriptors still exist',
    '2C000' => 'invalid character set name',
    '2D000' => 'invalid transaction termination',
    '2E000' => 'invalid connection name',
    '2F000' => 'SQL routine exception',
    '2F002' => 'modifying SQL-data not permitted',
    '2F003' => 'prohibited SQL-statement attempted',
    '2F004' => 'reading SQL-data not permitted',
    '2F005' => 'function executed no return statement',
    '2H000' => 'invalid collation name',
    '30000' => 'invalid SQL statement identifier',
    '33000' => 'invalid SQL descriptor name',
    '34000' => 'invalid cursor name',
    '35000' => 'invalid condition number',
    '36000' => 'cursor sensitivity exception',
    '36001' => 'request rejected',
    '36002' => 'request failed',
    '38000' => 'external routine exception',
    '38001' => 'containing SQL not permitted',
    '38002' => 'modifying SQL-data not permitted',
    '38003' => 'prohibited SQL-statement attempted',
    '38004' => 'reading SQL-data not permitted',
    '39000' => 'external routine invocation exception',
    '39004' => 'null value not allowed',
    '3B000' => 'savepoint exception',
    '3B001' => 'invalid specification',
    '3B002' => 'too many',
    '3C000' => 'ambiguous cursor name',
    '3D000' => 'invalid catalog name',
    '3F000' => 'invalid schema name',
    '40000' => 'transaction rollback',
    '40001' => 'serialization failure',
    '40002' => 'integrity constraint violation',
    '40003' => 'statement completion unknown',
    '40004' => 'triggered action exception',
    '42000' => 'syntax error or access rule violation',
    '44000' => 'with check option violation',
    '45000' => 'unhandled user-defined exception',
    '46000' => 'OLB-specific error',
    '46001' => 'invalid URL',
    '46002' => 'invalid JAR name',
    '46003' => 'invalid class deletion',
    '46005' => 'invalid replacement',
    '4600A' => 'attempt to replace uninstalled JAR',
    '4600B' => 'attempt to remove uninstalled JAR',
    '4600C' => 'invalid JAR removal',
    '4600D' => 'invalid path',
    '4600E' => 'self-referencing path',
    '46102' => 'invalid JAR name in path',
    '46103' => 'unresolved class name',
    '46110' => 'unsupported feature',
    '46120' => 'invalid class declaration',
    '46121' => 'invalid column name',
    '46122' => 'invalid number of columns',
    '46130' => 'invalid profile state',
    'HV000' => 'FDW-specific condition',
    'HV001' => 'memory allocation error',
    'HV002' => 'dynamic parameter value needed',
    'HV004' => 'invalid data type',
    'HV005' => 'column name not found',
    'HV006' => 'invalid data type descriptors',
    'HV007' => 'invalid column name',
    'HV008' => 'invalid column number',
    'HV009' => 'invalid use of null pointer',
    'HV00A' => 'invalid string format',
    'HV00B' => 'invalid handle',
    'HV00C' => 'invalid option index',
    'HV00D' => 'invalid option name',
    'HV00J' => 'option name not found',
    'HV00K' => 'reply handle',
    'HV00L' => 'unable to create execution',
    'HV00M' => 'unable to create reply',
    'HV00N' => 'unable to establish connection',
    'HV00P' => 'no schemas',
    'HV00Q' => 'schema not found',
    'HV00R' => 'table not found',
    'HV010' => 'function sequence error',
    'HV014' => 'limit on number of handles exceeded',
    'HV021' => 'inconsistent descriptor information',
    'HV024' => 'invalid attribute value',
    'HV090' => 'invalid string length or buffer length',
    'HV091' => 'invalid descriptor field identifier',
    'HW000' => 'datalink exception',
    'HW001' => 'external file not linked',
    'HW002' => 'external file already linked',
    'HW003' => 'referenced file does not exist',
    'HW004' => 'invalid write token',
    'HW005' => 'invalid datalink construction',
    'HW006' => 'invalid write permission for update',
    'HW007' => 'referenced file not valid',
    'HY000' => 'CLI-specific condition',
    'HY001' => 'memory allocation error',
    'HY003' => 'invalid data type in application descriptor',
    'HY004' => 'invalid data type',
    'HY007' => 'associated statement is not prepared',
    'HY008' => 'operation canceled',
    'HY009' => 'invalid use of null pointer',
    'HY010' => 'function sequence error',
    'HY011' => 'attribute cannot be set now',
    'HY012' => 'invalid transaction operation code',
    'HY013' => 'memory management error',
    'HY014' => 'limit on number of handles exceeded',
    'HY017' => 'invalid use of automatically allocated descriptor handle',
    'HY018' => 'server declined the cancellation request',
    'HY019' => 'non-string data cannot be sent in pieces',
    'HY020' => 'attempt to concatenate a null value',
    'HY021' => 'inconsistent descriptor information',
    'HY024' => 'invalid attribute value',
    'HY055' => 'non-string data cannot be used with string routine',
    'HY090' => 'invalid string length or buffer length',
    'HY091' => 'invalid descriptor field identifier',
    'HY092' => 'invalid attribute identifier',
    'HY093' => 'invalid datalink value',
    'HY095' => 'invalid FunctionId specified',
    'HY096' => 'invalid information type',
    'HY097' => 'column type out of range',
    'HY098' => 'scope out of range',
    'HY099' => 'nullable type out of range',
    'HY103' => 'invalid retrieval code',
    'HY104' => 'invalid LengthPrecision value',
    'HY105' => 'invalid parameter mode',
    'HY106' => 'invalid fetch orientation',
    'HY107' => 'row value out of range',
    'HY108' => 'invalid cursor position',
    'HY???' => 'invalid handle',
    'HYC00' => 'optional feature not implemented',
    'HZ???' => 'Reserved for ISO9579 (RDA)',
);

1;
